@@ -24,9 +24,9 @@ pub struct Torrent {
 
 #[serde_with::skip_serializing_none]
 #[derive(Debug, Serialize)]
-pub struct AddTorrent {
-	pub filename: Option<String>,
-	pub metainfo: Option<String>
+pub struct AddTorrent<'a> {
+	pub filename: Option<&'a str>,
+	pub metainfo: Option<&'a str>
 }
 
 #[derive(Debug, Deserialize, Serialize)]
